@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2020, Ilya Kotov <forkotov02@ya.ru>
+ * Copyright (c) 2014-2021, Ilya Kotov <forkotov02@ya.ru>
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -146,6 +146,9 @@ const QFont *Qt5CTPlatformTheme::font(QPlatformTheme::Font type) const
 
 QVariant Qt5CTPlatformTheme::themeHint(QPlatformTheme::ThemeHint hint) const
 {
+    if(m_isIgnored)
+        return QPlatformTheme::themeHint(hint);
+
     switch (hint)
     {
     case QPlatformTheme::CursorFlashTime:
@@ -194,8 +197,12 @@ QIcon Qt5CTPlatformTheme::fileIcon(const QFileInfo &fileInfo, QPlatformTheme::Ic
 
 void Qt5CTPlatformTheme::applySettings()
 {
-    if(!QGuiApplication::desktopSettingsAware())
+    if(!QGuiApplication::desktopSettingsAware() || m_isIgnored)
+    {
+        m_usePalette = false;
+        m_update = true;
         return;
+    }
 
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 5, 0))
     if(!m_update)
@@ -232,12 +239,16 @@ void Qt5CTPlatformTheme::applySettings()
         if(m_update && m_usePalette)
             qApp->setPalette(*m_palette);
 
-
-        //do not override application style
-        if(m_prevStyleSheet == qApp->styleSheet())
-            qApp->setStyleSheet(m_userStyleSheet);
-        else
+        // prepend our stylesheet to that of the application
+        // (first removing any previous stylesheet we have set)
+        QString appStyleSheet = qApp->styleSheet();
+        int prevIndex = appStyleSheet.indexOf(m_prevStyleSheet);
+        if (prevIndex >= 0) {
+            appStyleSheet.remove(prevIndex, m_prevStyleSheet.size());
+            qApp->setStyleSheet(m_userStyleSheet + appStyleSheet);
+        } else {
             qCDebug(lqt5ct) << "custom style sheet is disabled";
+        }
         m_prevStyleSheet = m_userStyleSheet;
     }
 #endif
@@ -376,8 +387,22 @@ void Qt5CTPlatformTheme::readSettings()
     QStringList qssPaths = settings.value("stylesheets").toStringList();
     m_userStyleSheet = loadStyleSheets(qssPaths);
 #endif
-
     settings.endGroup();
+
+    //load troubleshooting
+    if(!m_update)
+    {
+        settings.beginGroup("Troubleshooting");
+        m_isIgnored = settings.value("ignored_applications").toStringList().contains(QCoreApplication::applicationFilePath());
+        int forceRasterWidgets = settings.value("force_raster_widgets", Qt::PartiallyChecked).toInt();
+        if(!m_isIgnored && forceRasterWidgets == Qt::Checked)
+            QCoreApplication::setAttribute(Qt::AA_ForceRasterWidgets, true);
+        else if(!m_isIgnored && forceRasterWidgets == Qt::Unchecked)
+            QCoreApplication::setAttribute(Qt::AA_ForceRasterWidgets, false);
+        if(m_isIgnored)
+            m_usePalette = false;
+        settings.endGroup();
+    }
 }
 
 #ifdef QT_WIDGETS_LIB
@@ -398,9 +423,11 @@ QString Qt5CTPlatformTheme::loadStyleSheets(const QStringList &paths)
         QFile file(path);
         file.open(QIODevice::ReadOnly);
         content.append(QString::fromUtf8(file.readAll()));
+        if(!content.endsWith(QChar::LineFeed))
+            content.append(QChar::LineFeed);
     }
-    QRegularExpression regExp("//.*(\\n|$)");
-    content.remove(regExp);
+    QRegularExpression regExp("//.*\n");
+    content.replace(regExp, "\n");
     return content;
 }
 
