@@ -135,7 +135,7 @@
     <message>
         <location filename="../appearancepage.cpp" line="199"/>
         <source>Are you sure you want to remove color scheme &quot;%1&quot;?</source>
-        <translation>Er du sikker på, at du vil fjerne farveskema &quot;%1&quot;?</translation>
+        <translation>Er du sikker på, at du vil fjerne farveskemaet &quot;%1&quot;?</translation>
     </message>
     <message>
         <location filename="../appearancepage.cpp" line="219"/>
@@ -179,7 +179,7 @@
     <message>
         <location filename="../fontconfigdialog.ui" line="67"/>
         <source>Font resolution:</source>
-        <translation>Skriftypeopløsning:</translation>
+        <translation>Opløsning for skrift:</translation>
     </message>
     <message>
         <location filename="../fontconfigdialog.ui" line="110"/>
@@ -189,7 +189,7 @@
     <message>
         <location filename="../fontconfigdialog.ui" line="83"/>
         <source>Subpixel geometry:</source>
-        <translation>Underpixel geometri:</translation>
+        <translation>Geometri for underpixel:</translation>
     </message>
     <message>
         <location filename="../fontconfigdialog.ui" line="90"/>
@@ -199,7 +199,7 @@
     <message>
         <location filename="../fontconfigdialog.ui" line="97"/>
         <source>Hinting style:</source>
-        <translation>Hintingstil:</translation>
+        <translation>Stil for hinting:</translation>
     </message>
     <message>
         <location filename="../fontconfigdialog.cpp" line="42"/>
@@ -332,7 +332,7 @@
     <message>
         <location filename="../interfacepage.ui" line="175"/>
         <source>Enable gui effects</source>
-        <translation>Aktivér effekter til grafisk brugerflade</translation>
+        <translation>Aktivér brugerfladeeffekter</translation>
     </message>
     <message>
         <location filename="../interfacepage.ui" line="182"/>
@@ -367,12 +367,12 @@
     <message>
         <location filename="../interfacepage.ui" line="239"/>
         <source>Mouse wheel scroll lines:</source>
-        <translation>Linjer som musehjulet ruller:</translation>
+        <translation>Rullelinjer for musehjul:</translation>
     </message>
     <message>
         <location filename="../interfacepage.ui" line="256"/>
         <source>Show shortcut underlines</source>
-        <translation>Vis understregning af genveje</translation>
+        <translation>Vis understregninger for genveje</translation>
     </message>
     <message>
         <location filename="../interfacepage.ui" line="266"/>
@@ -392,17 +392,17 @@
     <message>
         <location filename="../interfacepage.cpp" line="63"/>
         <source>The text appears beside the icon</source>
-        <translation>Tekst ved siden af ikonet</translation>
+        <translation>Teksten vises ved siden af ikonet</translation>
     </message>
     <message>
         <location filename="../interfacepage.cpp" line="64"/>
         <source>The text appears under the icon</source>
-        <translation>Tekst under ikonet</translation>
+        <translation>Teksten vises under ikonet</translation>
     </message>
     <message>
         <location filename="../interfacepage.cpp" line="65"/>
         <source>Follow the application style</source>
-        <translation>Følg programmets stil</translation>
+        <translation>Følg programstilen</translation>
     </message>
 </context>
 <context>
@@ -428,57 +428,62 @@
         <translation>Skjul</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="49"/>
+        <location filename="../mainwindow.cpp" line="50"/>
         <source>Appearance</source>
         <translation>Udseende</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="50"/>
+        <location filename="../mainwindow.cpp" line="51"/>
         <source>Fonts</source>
         <translation>Skrifttyper</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="51"/>
+        <location filename="../mainwindow.cpp" line="52"/>
         <source>Icon Theme</source>
         <translation>Ikontema</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="52"/>
+        <location filename="../mainwindow.cpp" line="53"/>
         <source>Interface</source>
         <translation>Grænseflade</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="54"/>
+        <location filename="../mainwindow.cpp" line="55"/>
         <source>Style Sheets</source>
         <translation>Typografiark</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="62"/>
+        <location filename="../mainwindow.cpp" line="57"/>
+        <source>Troubleshooting</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="64"/>
         <source>Version: %1</source>
         <translation>Version: %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="107"/>
+        <location filename="../mainwindow.cpp" line="109"/>
         <source>Warning</source>
         <translation>Advarsel</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="116"/>
+        <location filename="../mainwindow.cpp" line="118"/>
         <source>Please remove the &lt;b&gt;QT_STYLE_OVERRIDE&lt;/b&gt; environment variable (current value: &lt;b&gt;%1&lt;/b&gt;).</source>
         <translation>Fjern venligst miljøvariablen &lt;b&gt;QT_STYLE_OVERRIDE&lt;/b&gt; (nuværende værdi: &lt;b&gt;%1&lt;/b&gt;).</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="122"/>
+        <location filename="../mainwindow.cpp" line="124"/>
         <source>The &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; environment variable is not set (required value: &lt;b&gt;qt5ct&lt;/b&gt;).</source>
-        <translation>Miljøvariablen &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; er ikke sat (krævet værdi: &lt;b&gt;qt5ct&lt;/b&gt;).</translation>
+        <translation>Miljøvariablen &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; er ikke indstillet (krævet værdi: &lt;b&gt;qt5ct&lt;/b&gt;).</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="126"/>
+        <location filename="../mainwindow.cpp" line="128"/>
         <source>The &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; environment variable is not set correctly (current value: &lt;b&gt;%1&lt;/b&gt;, required value: &lt;b&gt;qt5ct&lt;/b&gt;).</source>
-        <translation>Miljøvariablen &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; er ikke sat korrekt (nuværende værdi: &lt;b&gt;%1&lt;/b&gt;, krævet værdi: &lt;b&gt;qt5ct&lt;/b&gt;).</translation>
+        <translation>Miljøvariablen &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; er ikke indstillet korrekt (nuværende værdi: &lt;b&gt;%1&lt;/b&gt;, krævet værdi: &lt;b&gt;qt5ct&lt;/b&gt;).</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="133"/>
+        <location filename="../mainwindow.cpp" line="135"/>
         <source>Unable to find &lt;b&gt;libqt5ct-style.so&lt;/b&gt;</source>
         <translation>Kan ikke finde &lt;b&gt;libqt5ct-style.so&lt;/b&gt;</translation>
     </message>
@@ -533,7 +538,7 @@
     <message>
         <location filename="../paletteeditdialog.cpp" line="91"/>
         <source>Button background</source>
-        <translation>Knap baggrund</translation>
+        <translation>Baggrund for knap</translation>
     </message>
     <message>
         <location filename="../paletteeditdialog.cpp" line="91"/>
@@ -568,7 +573,7 @@
     <message>
         <location filename="../paletteeditdialog.cpp" line="92"/>
         <source>Button text</source>
-        <translation>Knap tekst</translation>
+        <translation>Tekst for knap</translation>
     </message>
     <message>
         <location filename="../paletteeditdialog.cpp" line="92"/>
@@ -583,12 +588,12 @@
     <message>
         <location filename="../paletteeditdialog.cpp" line="93"/>
         <source>Highlight</source>
-        <translation>Markeret</translation>
+        <translation>Fremhævning</translation>
     </message>
     <message>
         <location filename="../paletteeditdialog.cpp" line="93"/>
         <source>Highlighted text</source>
-        <translation>Markeret tekst</translation>
+        <translation>Fremhævet tekst</translation>
     </message>
     <message>
         <location filename="../paletteeditdialog.cpp" line="93"/>
@@ -603,12 +608,12 @@
     <message>
         <location filename="../paletteeditdialog.cpp" line="94"/>
         <source>Tooltip background</source>
-        <translation>Værktøjstip baggrund</translation>
+        <translation>Baggrund for værktøjstip</translation>
     </message>
     <message>
         <location filename="../paletteeditdialog.cpp" line="94"/>
         <source>Tooltip text</source>
-        <translation>Værktøjstip tekst</translation>
+        <translation>Tekst for værktøjstip</translation>
     </message>
     <message>
         <location filename="../paletteeditdialog.cpp" line="93"/>
@@ -618,12 +623,12 @@
     <message>
         <location filename="../paletteeditdialog.cpp" line="94"/>
         <source>Alternate background</source>
-        <translation>Alternativ baggrund</translation>
+        <translation>Skift baggrund</translation>
     </message>
     <message>
         <location filename="../paletteeditdialog.cpp" line="96"/>
         <source>Placeholder text</source>
-        <translation>Pladsholder tekst</translation>
+        <translation>Pladsholdertekst</translation>
     </message>
     <message>
         <location filename="../paletteeditdialog.cpp" line="109"/>
@@ -661,7 +666,7 @@
     <message>
         <location filename="../previewform.ui" line="84"/>
         <source>CheckBox</source>
-        <translation>Tjekboks</translation>
+        <translation>Afkrydsningsboks</translation>
     </message>
 </context>
 <context>
@@ -747,7 +752,7 @@
     <message>
         <location filename="../qsspage.cpp" line="152"/>
         <source>Are you sure you want to remove style sheet &quot;%1&quot;?</source>
-        <translation>Er du sikker på, at du vil fjerne typografiark &quot;%1&quot;?</translation>
+        <translation>Er du sikker på, at du vil fjerne typografiarket &quot;%1&quot;?</translation>
     </message>
     <message>
         <location filename="../qsspage.cpp" line="208"/>
@@ -781,4 +786,47 @@
         <translation>Kan ikke kopiere fil</translation>
     </message>
 </context>
+<context>
+    <name>TroubleshootingPage</name>
+    <message>
+        <location filename="../troubleshootingpage.ui" line="20"/>
+        <source>Ignored applications:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../troubleshootingpage.ui" line="29"/>
+        <source>Add...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../troubleshootingpage.ui" line="40"/>
+        <source>Remove</source>
+        <translation type="unfinished">Fjern</translation>
+    </message>
+    <message>
+        <location filename="../troubleshootingpage.ui" line="73"/>
+        <source>Do not apply any styles and color schemes for the listed applications.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../troubleshootingpage.ui" line="82"/>
+        <source>Make top-level widgets use pure raster surfaces, and do not support non-native GL-based child widgets.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../troubleshootingpage.ui" line="85"/>
+        <source>Force raster surface</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../troubleshootingpage.cpp" line="64"/>
+        <source>Select Application</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../troubleshootingpage.cpp" line="64"/>
+        <source>Executable files (*)</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 </TS>
