@@ -11,7 +11,7 @@
     <message>
         <location filename="../appearancepage.ui" line="59"/>
         <source>Preview</source>
-        <translation>Voorbeeld</translation>
+        <translation>Voorvertoning</translation>
     </message>
     <message>
         <location filename="../appearancepage.ui" line="69"/>
@@ -52,7 +52,7 @@
     <message>
         <location filename="../appearancepage.ui" line="187"/>
         <source>...</source>
-        <translation>...</translation>
+        <translation>…</translation>
     </message>
     <message>
         <location filename="../appearancepage.ui" line="218"/>
@@ -62,7 +62,7 @@
     <message>
         <location filename="../appearancepage.cpp" line="71"/>
         <source>Create</source>
-        <translation>Creëren</translation>
+        <translation>Maken</translation>
     </message>
     <message>
         <location filename="../appearancepage.cpp" line="72"/>
@@ -72,7 +72,7 @@
     <message>
         <location filename="../appearancepage.cpp" line="73"/>
         <source>Create a Copy</source>
-        <translation>Kopie creëren</translation>
+        <translation>Kopie maken</translation>
     </message>
     <message>
         <location filename="../appearancepage.cpp" line="74"/>
@@ -89,7 +89,7 @@
         <location filename="../appearancepage.cpp" line="217"/>
         <location filename="../appearancepage.cpp" line="256"/>
         <source>Enter Color Scheme Name</source>
-        <translation>Voer een naam in voor dit kleurenschema</translation>
+        <translation>Geef dit kleurenschema een naam</translation>
     </message>
     <message>
         <location filename="../appearancepage.cpp" line="143"/>
@@ -111,7 +111,7 @@
         <location filename="../appearancepage.cpp" line="228"/>
         <location filename="../appearancepage.cpp" line="266"/>
         <source>The color scheme &quot;%1&quot; already exists</source>
-        <translation>Het kleurenschema &quot;%1&quot; bestaat al</translation>
+        <translation>Het kleurenschema “%1” bestaat al</translation>
     </message>
     <message>
         <location filename="../appearancepage.cpp" line="170"/>
@@ -125,7 +125,7 @@
         <location filename="../appearancepage.cpp" line="193"/>
         <location filename="../appearancepage.cpp" line="251"/>
         <source>The color scheme &quot;%1&quot; is read only</source>
-        <translation>Het kleurenschema &quot;%1&quot; is alleen-lezen</translation>
+        <translation>Het kleurenschema “%1” is alleen-lezen</translation>
     </message>
     <message>
         <location filename="../appearancepage.cpp" line="198"/>
@@ -135,7 +135,7 @@
     <message>
         <location filename="../appearancepage.cpp" line="199"/>
         <source>Are you sure you want to remove color scheme &quot;%1&quot;?</source>
-        <translation>Weet je zeker dat je het kleurenschema &quot;%1&quot; wilt verwijderen?</translation>
+        <translation>Weet je zeker dat je het kleurenschema “%1” wilt verwijderen?</translation>
     </message>
     <message>
         <location filename="../appearancepage.cpp" line="219"/>
@@ -145,7 +145,7 @@
     <message>
         <location filename="../appearancepage.cpp" line="236"/>
         <source>Unable to copy file</source>
-        <translation>Kopiëren van bestand niet mogelijk</translation>
+        <translation>Het bestand kan niet worden gekopieerd</translation>
     </message>
 </context>
 <context>
@@ -236,7 +236,7 @@
         <location filename="../fontspage.ui" line="86"/>
         <location filename="../fontspage.ui" line="93"/>
         <source>...</source>
-        <translation>...</translation>
+        <translation>…</translation>
     </message>
     <message>
         <location filename="../fontspage.ui" line="60"/>
@@ -246,12 +246,12 @@
     <message>
         <location filename="../fontspage.ui" line="100"/>
         <source>Fixed width:</source>
-        <translation>Vastgezette breedte:</translation>
+        <translation>Vaste breedte:</translation>
     </message>
     <message>
         <location filename="../fontspage.ui" line="125"/>
         <source>Create  fonts.conf</source>
-        <translation>fonts.conf creëren</translation>
+        <translation>fonts.conf samenstellen</translation>
     </message>
     <message>
         <location filename="../fontspage.ui" line="132"/>
@@ -289,12 +289,12 @@
     <message>
         <location filename="../interfacepage.ui" line="56"/>
         <source>ToolTip effect:</source>
-        <translation>Hulpballon-effect:</translation>
+        <translation>Hulpballoneffect:</translation>
     </message>
     <message>
         <location filename="../interfacepage.ui" line="63"/>
         <source>ToolBox effect:</source>
-        <translation>Gereedschapsvenster-effect:</translation>
+        <translation>Gereedschapsvenstereffect:</translation>
     </message>
     <message>
         <location filename="../interfacepage.ui" line="70"/>
@@ -362,7 +362,7 @@
     <message>
         <location filename="../interfacepage.ui" line="229"/>
         <source>Toolbar button style:</source>
-        <translation>Werkbalkknop-stijl:</translation>
+        <translation>Werkbalkknopstijl:</translation>
     </message>
     <message>
         <location filename="../interfacepage.ui" line="239"/>
@@ -372,12 +372,12 @@
     <message>
         <location filename="../interfacepage.ui" line="256"/>
         <source>Show shortcut underlines</source>
-        <translation>Snelkoppelingen onderstrepen</translation>
+        <translation>Sneltoetsacties onderstrepen</translation>
     </message>
     <message>
         <location filename="../interfacepage.ui" line="266"/>
         <source>Show shortcuts in context menus</source>
-        <translation>Sneltoetsen tonen in rechtermuisknopmenu&apos;s</translation>
+        <translation>Sneltoetsacties tonen in rechtermuisknopmenu&apos;s</translation>
     </message>
     <message>
         <location filename="../interfacepage.cpp" line="61"/>
@@ -402,7 +402,7 @@
     <message>
         <location filename="../interfacepage.cpp" line="65"/>
         <source>Follow the application style</source>
-        <translation>Applicatiestijl volgen</translation>
+        <translation>Programmastijl volgen</translation>
     </message>
 </context>
 <context>
@@ -415,7 +415,7 @@
     <message>
         <location filename="../mainwindow.ui" line="45"/>
         <source>The application is not configured correctly.</source>
-        <translation>De applicatie is onjuist ingesteld.</translation>
+        <translation>Het programma is niet goed ingesteld.</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="52"/>
@@ -428,59 +428,64 @@
         <translation>Verbergen</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="49"/>
+        <location filename="../mainwindow.cpp" line="50"/>
         <source>Appearance</source>
-        <translation>Uiterlijk</translation>
+        <translation>Vormgeving</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="50"/>
+        <location filename="../mainwindow.cpp" line="51"/>
         <source>Fonts</source>
         <translation>Lettertypen</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="51"/>
+        <location filename="../mainwindow.cpp" line="52"/>
         <source>Icon Theme</source>
         <translation>Pictogramthema</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="52"/>
+        <location filename="../mainwindow.cpp" line="53"/>
         <source>Interface</source>
         <translation>Uiterlijk</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="54"/>
+        <location filename="../mainwindow.cpp" line="55"/>
         <source>Style Sheets</source>
         <translation>Stijlbladen</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="62"/>
+        <location filename="../mainwindow.cpp" line="57"/>
+        <source>Troubleshooting</source>
+        <translation>Probleemoplossing</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="64"/>
         <source>Version: %1</source>
         <translation>Versie: %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="107"/>
+        <location filename="../mainwindow.cpp" line="109"/>
         <source>Warning</source>
         <translation>Waarschuwing</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="116"/>
+        <location filename="../mainwindow.cpp" line="118"/>
         <source>Please remove the &lt;b&gt;QT_STYLE_OVERRIDE&lt;/b&gt; environment variable (current value: &lt;b&gt;%1&lt;/b&gt;).</source>
         <translation>Verwijder de omgevingsvariabel &lt;b&gt;QT_STYLE_OVERRIDE&lt;/b&gt; (huidige waarde: &lt;b&gt;%1&lt;/b&gt;).</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="122"/>
+        <location filename="../mainwindow.cpp" line="124"/>
         <source>The &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; environment variable is not set (required value: &lt;b&gt;qt5ct&lt;/b&gt;).</source>
         <translation>De omgevingsvariabel &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; is niet ingesteld (vereiste waarde: &lt;b&gt;qt5ct&lt;/b&gt;).</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="126"/>
+        <location filename="../mainwindow.cpp" line="128"/>
         <source>The &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; environment variable is not set correctly (current value: &lt;b&gt;%1&lt;/b&gt;, required value: &lt;b&gt;qt5ct&lt;/b&gt;).</source>
-        <translation>De omgevingsvariabel &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; is onjuist ingesteld (huidige waarde: &lt;b&gt;%1&lt;/b&gt; - vereiste waarde: &lt;b&gt;qt5ct&lt;/b&gt;).</translation>
+        <translation>De omgevingsvariabel &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; is niet goed ingesteld (huidige waarde: &lt;b&gt;%1&lt;/b&gt; - vereiste waarde: &lt;b&gt;qt5ct&lt;/b&gt;).</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="133"/>
+        <location filename="../mainwindow.cpp" line="135"/>
         <source>Unable to find &lt;b&gt;libqt5ct-style.so&lt;/b&gt;</source>
-        <translation>&lt;b&gt;libqt5ct-style.so&lt;/b&gt; kan niet worden gevonden.</translation>
+        <translation>&lt;b&gt;libqt5ct-style.so&lt;/b&gt; is niet aangetroffen.</translation>
     </message>
 </context>
 <context>
@@ -488,22 +493,22 @@
     <message>
         <location filename="../paletteeditdialog.ui" line="14"/>
         <source>Palette Editor</source>
-        <translation>Kleurenschema-bewerker</translation>
+        <translation>Kleurenschemabewerker</translation>
     </message>
     <message>
         <location filename="../paletteeditdialog.ui" line="79"/>
         <source>Reset palette</source>
-        <translation>Standaardwaarden</translation>
+        <translation>Standaardwaarden terugzetten</translation>
     </message>
     <message>
         <location filename="../paletteeditdialog.ui" line="29"/>
         <source>Build inactive palette</source>
-        <translation>Inactief kleurenschema bouwen</translation>
+        <translation>Inactief kleurenschema samenstellen</translation>
     </message>
     <message>
         <location filename="../paletteeditdialog.ui" line="36"/>
         <source>Build disabled palette</source>
-        <translation>Uitgeschakeld kleurenschema bouwen</translation>
+        <translation>Uitgeschakeld kleurenschema samenstellen</translation>
     </message>
     <message>
         <location filename="../paletteeditdialog.cpp" line="49"/>
@@ -583,7 +588,7 @@
     <message>
         <location filename="../paletteeditdialog.cpp" line="93"/>
         <source>Highlight</source>
-        <translation>Markeren</translation>
+        <translation>Markering</translation>
     </message>
     <message>
         <location filename="../paletteeditdialog.cpp" line="93"/>
@@ -682,7 +687,7 @@
     <message>
         <location filename="../qsspage.ui" line="23"/>
         <source>Create</source>
-        <translation>Creëren</translation>
+        <translation>Maken</translation>
     </message>
     <message>
         <location filename="../qsspage.ui" line="66"/>
@@ -706,7 +711,7 @@
     <message>
         <location filename="../qsspage.cpp" line="52"/>
         <source>Create a Copy</source>
-        <translation>Kopie creëren</translation>
+        <translation>Kopie maken</translation>
     </message>
     <message>
         <location filename="../qsspage.cpp" line="92"/>
@@ -723,7 +728,7 @@
         <location filename="../qsspage.cpp" line="106"/>
         <location filename="../qsspage.cpp" line="251"/>
         <source>Enter Style Sheet Name</source>
-        <translation>Voer een naam in voor dit stijlblad</translation>
+        <translation>Geef dit stijlblad een naam</translation>
     </message>
     <message>
         <location filename="../qsspage.cpp" line="117"/>
@@ -732,12 +737,12 @@
         <location filename="../qsspage.cpp" line="263"/>
         <location filename="../qsspage.cpp" line="271"/>
         <source>Error</source>
-        <translation>Fout</translation>
+        <translation>Foutmelding</translation>
     </message>
     <message>
         <location filename="../qsspage.cpp" line="117"/>
         <source>The file &quot;%1&quot; already exists</source>
-        <translation>Het bestand &quot;%1&quot; bestaat al</translation>
+        <translation>Het bestand “%1” bestaat al</translation>
     </message>
     <message>
         <location filename="../qsspage.cpp" line="151"/>
@@ -747,7 +752,7 @@
     <message>
         <location filename="../qsspage.cpp" line="152"/>
         <source>Are you sure you want to remove style sheet &quot;%1&quot;?</source>
-        <translation>Weet je zeker dat je het stijlblad &quot;%1&quot; wilt verwijderen?</translation>
+        <translation>Weet je zeker dat je het stijlblad “%1” wilt verwijderen?</translation>
     </message>
     <message>
         <location filename="../qsspage.cpp" line="208"/>
@@ -763,12 +768,12 @@
         <location filename="../qsspage.cpp" line="218"/>
         <location filename="../qsspage.cpp" line="263"/>
         <source>The style sheet &quot;%1&quot; already exists</source>
-        <translation>Het stijlblad &quot;%1&quot; bestaat al</translation>
+        <translation>Het stijlblad “%1” bestaat al</translation>
     </message>
     <message>
         <location filename="../qsspage.cpp" line="226"/>
         <source>Unable to rename file</source>
-        <translation>Het wijzigen van de bestandsnaam is mislukt</translation>
+        <translation>De bestandsnaam kan niet worden gewijzigd</translation>
     </message>
     <message>
         <location filename="../qsspage.cpp" line="253"/>
@@ -778,7 +783,50 @@
     <message>
         <location filename="../qsspage.cpp" line="271"/>
         <source>Unable to copy file</source>
-        <translation>Kan bestand niet kopiëren</translation>
+        <translation>Het bestand kan niet worden gekopieerd</translation>
+    </message>
+</context>
+<context>
+    <name>TroubleshootingPage</name>
+    <message>
+        <location filename="../troubleshootingpage.ui" line="20"/>
+        <source>Ignored applications:</source>
+        <translation>Genegeerde programma&apos;s:</translation>
+    </message>
+    <message>
+        <location filename="../troubleshootingpage.ui" line="29"/>
+        <source>Add...</source>
+        <translation>Toevoegen…</translation>
+    </message>
+    <message>
+        <location filename="../troubleshootingpage.ui" line="40"/>
+        <source>Remove</source>
+        <translation>Verwijderen</translation>
+    </message>
+    <message>
+        <location filename="../troubleshootingpage.ui" line="73"/>
+        <source>Do not apply any styles and color schemes for the listed applications.</source>
+        <translation>Pas geen stijlen en kleurenschema&apos;s toe op programma&apos;s op deze lijst.</translation>
+    </message>
+    <message>
+        <location filename="../troubleshootingpage.ui" line="82"/>
+        <source>Make top-level widgets use pure raster surfaces, and do not support non-native GL-based child widgets.</source>
+        <translation>Dit zorgt er voor dat zichtbare elementen worden uitgelijnd op een rooster en geen ondersteuning hebben voor onderliggende OpenGL-widgets.</translation>
+    </message>
+    <message>
+        <location filename="../troubleshootingpage.ui" line="85"/>
+        <source>Force raster surface</source>
+        <translation>Rooster afdwingen</translation>
+    </message>
+    <message>
+        <location filename="../troubleshootingpage.cpp" line="64"/>
+        <source>Select Application</source>
+        <translation>Kies een programma</translation>
+    </message>
+    <message>
+        <location filename="../troubleshootingpage.cpp" line="64"/>
+        <source>Executable files (*)</source>
+        <translation>Uitvoerbare bestanden (*)</translation>
     </message>
 </context>
 </TS>
